package com.bofeng.controller;

import com.bofeng.dao.UserRoleMapper;
import com.bofeng.entity.UserOpen;
import com.bofeng.entity.UserRole;
import com.bofeng.service.HomeService;
import com.bofeng.service.WxUserOpenService;
import com.yvan.Model;
import com.yvan.platform.StringUtils;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.List;

@RestController
public class WxUserOpenController {

    @Autowired
    private HomeService homeService;
    @Autowired
    private UserRoleMapper userRoleMapper;
    @Autowired
    private WxUserOpenService wxUserOpenService;

    @ApiOperation("用户注册页面点登录")
    @GetMapping("/userOpen/login")
    public Model<Long> login() {
        UserOpen userOpen = homeService.getUserOpen();
        if (userOpen == null) {
            return Model.newFail("微信登录失败");
        }
        //成功返回用户Id
        return Model.newSuccess(userOpen.getUserId());
    }

    @ApiOperation("身份录入之创建角色(家庭用户或业委会成员)")
    @PostMapping("/userOpen/createRole")
    public Model<Long> createRole(HttpServletRequest request) throws Exception {
        Long isFamily = Long.parseLong(request.getParameter("isFamily"));
        Long isYWH = Long.parseLong(request.getParameter("isYWH"));
        if (isFamily == 0L && isYWH == 0L) {
            return Model.newFail("请至少选择一个角色");
        }
        //成功返回用户Id
        return Model.newSuccess(wxUserOpenService.createRole(isFamily, isYWH));
    }

    @ApiOperation("完善基础数据之获取创建的角色")
    @GetMapping("/userOpen/queryUserRoles")
    public Model<List<UserRole>> queryUserRoles() {
        UserOpen userOpen = homeService.getUserOpen();
        List<UserRole> list = new ArrayList<>();
        if (userOpen.getUserId() > 0L) {
            list = userRoleMapper.getUserRoleByUserId(userOpen.getUserId());
        }
        if (list.size() == 0) {
            return Model.newFail("尚未创建任何角色");
        }
        //成功返回用户角色
        return Model.newSuccess(list);
    }

    @ApiOperation("完善家庭及住宅信息")
    @PostMapping("/userOpen/createFamily")
    public Model<Long> createFamily(HttpServletRequest request) throws Exception {
        Long unitId = Long.parseLong(request.getParameter("unitId"));
        String doorPlate = request.getParameter("doorPlate");
        String linkMan = request.getParameter("linkMan");
        Integer helpNum = Integer.parseInt(request.getParameter("helpNum"));
        String phone = request.getParameter("phone");
        if (unitId == null || unitId == 0L) {
            return Model.newFail("请选择所在单元");
        }
        if (StringUtils.isNullOrEmpty(doorPlate)) {
            return Model.newFail("请填写门牌号");
        }
        if (StringUtils.isNullOrEmpty(linkMan)) {
            return Model.newFail("请填写家庭联系人");
        }
        if (helpNum == null) {
            helpNum = 0;
        }
        if (StringUtils.isNullOrEmpty(phone)) {
            return Model.newFail("请填写家庭联系电话");
        }
        //成功返回用户Id
        return Model.newSuccess(wxUserOpenService.createFamily(unitId, doorPlate, linkMan, helpNum, phone));
    }

}
